function [m] = markers2(n)
% MARKERS generates symbol/colour markers suitable for scatter
% m = marker 
%    Returns a cell array of 91 marker strings.
%
% m = markers(n)
%    Returns the n^th marker string (starting from 0) of the
%    91 possible strings.
%
% Author: David Ross, June 18, 2003
%

% check the arguments
error(nargchk(0,1,nargin));

% if n not specified, enumerate the list of all possible markers
enumerate = (nargin == 0);

% possible colours (note white has been omitted)
colours = 'brcmgky';
% colours = 'brcmgwy';
% possible symbols
symbols = 'o+*xsd^<><ph.';


% if n not specified, enumerate the list of all possible markers
if enumerate
    m = {};
    
    for ii = 1:91
        cc = mod(ii, length(colours));
        ss = mod(ii, length(symbols));
        m{end+1} = [colours(cc+1) symbols(ss+1)];
    end
    
% if n specified, generate only the desired marker
else
    % use mod to wrap n around, in case n < 0 or n > 90
    cc = mod(n, length(colours));
    ss = mod(n, length(symbols));
    m = [symbols(ss+1) colours(cc+1)];
    
end
